require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spcertificatesettings',
  dscmeta_resource_friendly_name: 'SPCertificateSettings',
  dscmeta_resource_name: 'MSFT_SPCertificateSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPCertificateSettings resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_certificateexpirationattentionthreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the certificate expiration attention threshold',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_country: {
      type: 'Optional[String]',
      desc: 'Specifies the default country',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatenotificationcontacts: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the certificate notification contacts',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_organization: {
      type: 'Optional[String]',
      desc: 'Specifies the default organization',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_certificateexpirationwarningthreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the certificate expiration warning threshold',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_keyalgorithm: {
      type: "Optional[Enum['ECC', 'ecc', 'RSA', 'rsa']]",
      desc: 'Specifies the default key algorithm',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificateexpirationerrorthreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the certificate expiration error threshold',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_organizationalunit: {
      type: 'Optional[String]',
      desc: 'Specifies the default organizational unit',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ellipticcurve: {
      type: "Optional[Enum['nistP256', 'nistp256', 'nistP384', 'nistp384', 'nistP521', 'nistp521']]",
      desc: 'Specifies the default elliptic curve (Default=nistP256)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_keysize: {
      type: "Optional[Enum['0', '2048', '4096', '8192', '16384']]",
      desc: 'Specifies the default key size (Default=2048)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_hashalgorithm: {
      type: "Optional[Enum['SHA256', 'sha256', 'SHA384', 'sha384', 'SHA512', 'sha512']]",
      desc: 'Specifies the default hash algorithm (Default=SHA256',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: 'Optional[String]',
      desc: 'Specifies the default state',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes', 'yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_locality: {
      type: 'Optional[String]',
      desc: 'Specifies the default locality',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_rsasignaturepadding: {
      type: "Optional[Enum['Pkcs1', 'pkcs1', 'Pss', 'pss']]",
      desc: 'Specifies the default RSA signature padding (Default=Pkcs1)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
