require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spdesignersettings',
  dscmeta_resource_friendly_name: 'SPDesignerSettings',
  dscmeta_resource_name: 'MSFT_SPDesignerSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPDesignerSettings resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_settingsscope: {
      type: "Enum['WebApplication', 'webapplication', 'SiteCollection', 'sitecollection']",
      desc: 'Define the scope of the configuration - either WebApplication or SiteCollection',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_allowsavedeclarativeworkflowastemplate: {
      type: 'Optional[Boolean]',
      desc: 'Allow users to save declarative workflows as a template from SharePoint Designer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowdetachpagesfromdefinition: {
      type: 'Optional[Boolean]',
      desc: 'Allow pages to be un-ghosted by SharePoint Designer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowcustomisemasterpage: {
      type: 'Optional[Boolean]',
      desc: 'Allow masterpages to be changed by SharePoint Designer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowsharepointdesigner: {
      type: 'Optional[Boolean]',
      desc: 'Allow the use of SharePoint Designer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowcreatedeclarativeworkflow: {
      type: 'Optional[Boolean]',
      desc: 'Allow users to create declarative workflows with SharePoint Designer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web application or site collection to configure',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowsavepublishdeclarativeworkflow: {
      type: 'Optional[Boolean]',
      desc: 'Allow users to save and re-publish declarative workflows with SharePoint Designer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowmanagesiteurlstructure: {
      type: 'Optional[Boolean]',
      desc: 'Allow site URL structure to be changed by SharePoint Designer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
