require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spdistributedcacheclientsettings',
  dscmeta_resource_friendly_name: 'SPDistributedCacheClientSettings',
  dscmeta_resource_name: 'MSFT_SPDistributedCacheClientSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPDistributedCacheClientSettings resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_dspoatcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed SP OAuth Token Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_dfsptcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed File Store Performance Trace Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes', 'yes']",
      desc: "Unique key for the resource. Set to 'Yes' to apply configuration.",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dspcvcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed SP Certificate Validator Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_drtcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Resource Tally Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dafcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Activity Feed LMT Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dstacchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Server to Application Server Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dspoatcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed SP OAuth Token Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_duaucrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Unified Audit Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ddcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Default Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dacmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Access Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dltcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Logon Token Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dugcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Unified Groups Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dsgcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Stop Gap Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_duaucchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Unified Audit Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_drtcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Resource Tally Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dafrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Activity Feed Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dspoatcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed SP OAuth Token Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dvscrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed View State Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dvscchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed View State Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ddcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Default Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dspcvcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed SP Certificate Validator Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dspabscmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed SP Abs Blob Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dhscrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Health Score Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dswucrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Shared With User Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dfltcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed File Lock Throttler Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dspcvcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed SP Certificate Validator Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dacrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Access Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dswucchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Shared With User Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dfsptcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed File Store Performance Trace Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dhscmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Health Score Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dehcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Edge Header Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dbcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Bouncer Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dstacrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Server to Application Server Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dtcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Security Trimming Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dtcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Security Trimming Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_duacrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Unified Apps Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ddbfcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Db Level Failover Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dspabscrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed SP Abs Blob Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dafchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Activity Feed Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_drtcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Resource Tally Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dugcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Unified Groups Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dafcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Activity Feed LMT Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_duaucmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Unified Audit Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ddcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Default Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dafmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Activity Feed Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dltcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Logon Token Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dfsptcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed File Store Performance Trace Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dswucmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Shared With User Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dehcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Edge Header Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_duacchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Unified Apps Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dsgcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Stop Gap Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ddbfcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Db Level Failover Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dvscmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed View State Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dacchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Access Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dfltcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed File Lock Throttler Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dltcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Logon Token Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dbcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Bouncer Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_duacmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Unified Apps Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dscmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Search Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dhscchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Health Score Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dfltcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed File Lock Throttler Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dehcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Edge Header Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dscrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Search Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dtcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Security Trimming Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dugcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Unified Groups Cache (SP2016 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dstacmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Server to Application Server Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dsgcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Stop Gap Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dscchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Search Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dspabscchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed SP Abs Blob Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dbcrequesttimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Request timeout for the Distributed Bouncer Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dafcchannelopentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Channel timeout for the Distributed Activity Feed LMT Cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ddbfcmaxconnectionstoserver: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of connections to the Distributed Db Level Failover Cache (SP2019 and above)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
