require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spincomingemailsettings',
  dscmeta_resource_friendly_name: 'SPIncomingEmailSettings',
  dscmeta_resource_name: 'MSFT_SPIncomingEmailSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPIncomingEmailSettings resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_usedirectorymanagementservice: {
      type: "Optional[Enum['Yes', 'yes', 'No', 'no', 'Remote', 'remote']]",
      desc: 'Set to Yes, the service supports the creation and management of e-mail distribution groups from SharePoint Sites, and creates mail contacts mail enabled SharePoint lists. Set to Remote to use a remote SharePoint Directory Management Web Service',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_serverdisplayaddress: {
      type: 'Optional[String]',
      desc: "Email server display address 'mylist@example.com'",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Enum['Present', 'present', 'Absent', 'absent']",
      desc: 'Present ensures Incoming Email is enabled. Absent disables incoming email',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_remotedirectorymanagementurl: {
      type: 'Optional[String]',
      desc: 'URL to the remote SharePoint Directory Management Web Service',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_useautomaticsettings: {
      type: 'Optional[Boolean]',
      desc: 'Automatic Settings enables a local SMTP service on the SharePoint server. Set to False to use an external drop folder',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_dlsrequireauthenticatedsenders: {
      type: 'Optional[Boolean]',
      desc: 'SharePoint Distribution lists accept from authenticated senders only',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_dropfolder: {
      type: 'Optional[String]',
      desc: 'Path to email drop folder if not using Automatic Settings',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_serveraddress: {
      type: 'Optional[String]',
      desc: 'SMTP Server Address when Directory Managment Service mode is used',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes', 'yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_distributiongroupsenabled: {
      type: 'Optional[Boolean]',
      desc: 'Allow creation of distribution groups from within SharePoint',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
