require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spprojectserverusersyncsettings',
  dscmeta_resource_friendly_name: 'SPProjectServerUserSyncSettings',
  dscmeta_resource_name: 'MSFT_SPProjectServerUserSyncSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPProjectServerUserSyncSettings resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_enableprojectsitesync: {
      type: 'Boolean',
      desc: 'Enable Project Site Sync',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_url: {
      type: 'String',
      desc: 'The default zone URL of the Project site to set user sync settings for',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableprojectsitesyncforsptasklists: {
      type: 'Boolean',
      desc: 'Enable Project Site Sync for SharePoint Task List Projects',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enableprojectwebappsync: {
      type: 'Boolean',
      desc: 'Enable Project Web App Sync',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
