require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spsearchcontentsource',
  dscmeta_resource_friendly_name: 'SPSearchContentSource',
  dscmeta_resource_name: 'MSFT_SPSearchContentSource',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPSearchContentSource resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_priority: {
      type: "Optional[Enum['Normal', 'normal', 'High', 'high']]",
      desc: 'What is the priority on this content source',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_incrementalschedule: {
      type: "Optional[Struct[{
              crawlschedulemonthsofyear => Optional[Array[Enum['AllMonths', 'allmonths', 'January', 'january', 'February', 'february', 'March', 'march', 'April', 'april', 'May', 'may', 'June', 'june', 'July', 'july', 'August', 'august', 'September', 'september', 'October', 'october', 'November', 'november', 'December', 'december']]],
              crawlschedulerepeatinterval => Optional[Integer[0, 4294967295]],
              crawlscheduledaysofweek => Optional[Array[Enum['Everyday', 'everyday', 'Weekdays', 'weekdays', 'Weekends', 'weekends', 'Monday', 'monday', 'Tuesday', 'tuesday', 'Wednesday', 'wednesday', 'Thursday', 'thursday', 'Friday', 'friday', 'Saturday', 'saturday', 'Sunday', 'sunday']]],
              crawlschedulerepeatduration => Optional[Integer[0, 4294967295]],
              crawlscheduleruneveryinterval => Optional[Integer[0, 4294967295]],
              starthour => Optional[Integer[0, 4294967295]],
              crawlscheduledaysofmonth => Optional[Integer[0, 4294967295]],
              scheduletype => Enum['None', 'none', 'Daily', 'daily', 'Weekly', 'weekly', 'Monthly', 'monthly'],
              startminute => Optional[Integer[0, 4294967295]]
            }]]",
      desc: 'What is the incremental schedule for this content source',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPSearchCrawlSchedule',
      mof_is_embedded: true,
    },
    dsc_lobsystemset: {
      type: 'Optional[Array[String]]',
      desc: 'Line of Business System and System Instance names',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_limitserverhops: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many server hops should the crawler make (-1 = unlimtied, website sources only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_crawlsetting: {
      type: "Optional[Enum['CrawlEverything', 'crawleverything', 'CrawlFirstOnly', 'crawlfirstonly', 'CrawlVirtualServers', 'crawlvirtualservers', 'CrawlSites', 'crawlsites', 'Custom', 'custom']]",
      desc: 'Should the crawler index everything, just the first site or page, or a custom depth (applies to websites only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the content source',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present if the source should exist, absent if it should not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_serviceappname: {
      type: 'String',
      desc: 'The name of the search service app that this content source exists within',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_addresses: {
      type: 'Optional[Array[String]]',
      desc: 'A list of the addresses this content source includes',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_contentsourcetype: {
      type: "Enum['SharePoint', 'sharepoint', 'Website', 'website', 'FileShare', 'fileshare', 'Business', 'business']",
      desc: 'The type of content source - currently only SharePoint, Website, File Shares and Business are supported',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_limitpagedepth: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many pages deep should the crawler go (-1 = unlimited, website sources only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_continuouscrawl: {
      type: 'Optional[Boolean]',
      desc: 'Should this content source use continuous crawl (SharePoint sites only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_fullschedule: {
      type: "Optional[Struct[{
              crawlschedulemonthsofyear => Optional[Array[Enum['AllMonths', 'allmonths', 'January', 'january', 'February', 'february', 'March', 'march', 'April', 'april', 'May', 'may', 'June', 'june', 'July', 'july', 'August', 'august', 'September', 'september', 'October', 'october', 'November', 'november', 'December', 'december']]],
              crawlschedulerepeatinterval => Optional[Integer[0, 4294967295]],
              crawlscheduledaysofweek => Optional[Array[Enum['Everyday', 'everyday', 'Weekdays', 'weekdays', 'Weekends', 'weekends', 'Monday', 'monday', 'Tuesday', 'tuesday', 'Wednesday', 'wednesday', 'Thursday', 'thursday', 'Friday', 'friday', 'Saturday', 'saturday', 'Sunday', 'sunday']]],
              crawlschedulerepeatduration => Optional[Integer[0, 4294967295]],
              crawlscheduleruneveryinterval => Optional[Integer[0, 4294967295]],
              starthour => Optional[Integer[0, 4294967295]],
              crawlscheduledaysofmonth => Optional[Integer[0, 4294967295]],
              scheduletype => Enum['None', 'none', 'Daily', 'daily', 'Weekly', 'weekly', 'Monthly', 'monthly'],
              startminute => Optional[Integer[0, 4294967295]]
            }]]",
      desc: 'What is the full schedule for this content source',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPSearchCrawlSchedule',
      mof_is_embedded: true,
    },
    dsc_force: {
      type: 'Optional[Boolean]',
      desc: 'Specify true if DSC is allowed to delete and recreate a content source to apply the correct settings, otherwise false will just report errors if a change can not be applied.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
