require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spsearchmanagedproperty',
  dscmeta_resource_friendly_name: 'SPSearchManagedProperty',
  dscmeta_resource_name: 'MSFT_SPSearchManagedProperty',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPSearchManagedProperty resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_retrievable: {
      type: 'Optional[Boolean]',
      desc: 'Should the property be Retrievable',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the managed property',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sortable: {
      type: 'Optional[Boolean]',
      desc: 'Should the property be Sortable',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_nowordbreaker: {
      type: 'Optional[Boolean]',
      desc: 'Should the property only match exact content',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_searchable: {
      type: 'Optional[Boolean]',
      desc: 'Should the property be Searchable',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_propertytype: {
      type: "Enum['Binary', 'binary', 'DateTime', 'datetime', 'Decimal', 'decimal', 'Double', 'double', 'Integer', 'integer', 'Text', 'text', 'YesNo', 'yesno']",
      desc: 'The type of managed property - choose between Binary, DateTime, Decimal, Double, Integer, Text, and YesNo',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_includeallcrawledproperties: {
      type: 'Optional[Boolean]',
      desc: 'Should the property be mapped to all crawled properties',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present if the source should exist, absent if it should not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_serviceappname: {
      type: 'String',
      desc: 'The name of the search service app that this managed property exists within',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_hasmultiplevalues: {
      type: 'Optional[Boolean]',
      desc: 'Should the property allow for multiple values to be selected',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_refinable: {
      type: 'Optional[Boolean]',
      desc: 'Should the property be Refinable',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_safeforanonymous: {
      type: 'Optional[Boolean]',
      desc: 'Should the property be marked as safe for anonymous access',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_aliases: {
      type: 'Optional[Array[String]]',
      desc: 'Aliases of the managed property',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_tokennormalization: {
      type: 'Optional[Boolean]',
      desc: 'Should the property be case sensitive',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_queryable: {
      type: 'Optional[Boolean]',
      desc: 'Should the property be Queryable',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_crawledproperties: {
      type: 'Optional[Array[String]]',
      desc: 'List of crawled properties that the property is mapped with',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
