require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spshelladmins',
  dscmeta_resource_friendly_name: 'SPShellAdmins',
  dscmeta_resource_name: 'MSFT_SPShellAdmins',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPShellAdmins resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_memberstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'List of all accounts that must be in the Shell Admins group',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_members: {
      type: 'Optional[Array[String]]',
      desc: 'Exact list of accounts that will have to get Shell Admin permissions',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_memberstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'List of all accounts that are not allowed to have Shell Admin permissions',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_alldatabases: {
      type: 'Optional[Boolean]',
      desc: 'Specify if all databases must get the same config as the general config',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excludedatabases: {
      type: 'Optional[Array[String]]',
      desc: 'Specify all databases that must be excluded from AllDatabases',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_databases: {
      type: 'Optional[Array[Struct[{
              memberstoexclude => Optional[Array[String]],
              name => Optional[String],
              memberstoinclude => Optional[Array[String]],
              members => Optional[Array[String]],
            }]]]',
      desc: 'Shell Admin configuration of Databases',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPDatabasePermissions[]',
      mof_is_embedded: true,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes', 'yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
