require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spsite',
  dscmeta_resource_friendly_name: 'SPSite',
  dscmeta_resource_name: 'MSFT_SPSite',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPSite resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_template: {
      type: 'Optional[String]',
      desc: 'The template to apply to the site collection',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'The description to apply to the site collection',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'Optional[String]',
      desc: 'The display name of the site collection',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_administrationsitetype: {
      type: "Optional[Enum['TenantAdministration', 'tenantadministration', 'None', 'none']]",
      desc: 'Specifies the type of the site collection: Regular site or tenant administration site',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_owneremail: {
      type: 'Optional[String]',
      desc: 'The email address of the site collection administrator',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_contentdatabase: {
      type: 'Optional[String]',
      desc: 'The name of the content database to create the site in',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_hostheaderwebapplication: {
      type: 'Optional[String]',
      desc: 'The URL of the host header web application to create this site in',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_quotatemplate: {
      type: 'Optional[String]',
      desc: 'The quota template to apply to the site collection',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_createdefaultgroups: {
      type: 'Optional[Boolean]',
      desc: 'Create the default site groups in the site collection',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_owneralias: {
      type: 'String',
      desc: 'The username of the site collection administrator',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_secondaryowneralias: {
      type: 'Optional[String]',
      desc: 'The secondary site collection admin username',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_secondaryemail: {
      type: 'Optional[String]',
      desc: 'The secondary site collection admin email address',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_url: {
      type: 'String',
      desc: 'The URL of the site collection',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_language: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The language code of the site',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_compatibilitylevel: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The compatibility level of the site',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
