require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sptrustedsecuritytokenissuer',
  dscmeta_resource_friendly_name: 'SPTrustedSecurityTokenIssuer',
  dscmeta_resource_name: 'MSFT_SPTrustedSecurityTokenIssuer',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPTrustedSecurityTokenIssuer resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_metadataendpoint: {
      type: 'Optional[String]',
      desc: 'URL that SharePoint will reach to download the JSON metadata file of the issuer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present if the SPTrustedSecurityTokenIssuer should be created, or Absent if it should be removed',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of the SPTrustedSecurityTokenIssuer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_istrustbroker: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the trust is established with a self-issuer partner app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the SPTrustedSecurityTokenIssuer',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_registeredissuernamerealm: {
      type: 'Optional[String]',
      desc: 'The realm of the security token issuer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_signingcertificatethumbprint: {
      type: 'Optional[String]',
      desc: 'Specify the thumbprint of the signing certificate, which must be located in certificate store LocalMachine\My',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_registeredissuernameidentifier: {
      type: 'Optional[String]',
      desc: 'The security principal identifier of the security token issuer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_signingcertificatefilepath: {
      type: 'Optional[String]',
      desc: 'Specify the file path to the signing certificate if it is not stored in the local certificate store already',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
