require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwebappauthentication',
  dscmeta_resource_friendly_name: 'SPWebAppAuthentication',
  dscmeta_resource_name: 'MSFT_SPWebAppAuthentication',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPWebAppAuthentication resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_defaultsettings: {
      type: 'Optional[Struct[{
              customsigninpage => Optional[String],
              enableclientintegration => Optional[Boolean],
              requireuseremoteinterfaces => Optional[Boolean],
              anonymousauthentication => Optional[Boolean],
            }]]',
      desc: 'Specifies the zone settings for the Default zone.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppZoneSettings',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_intranetsettings: {
      type: 'Optional[Struct[{
              customsigninpage => Optional[String],
              enableclientintegration => Optional[Boolean],
              requireuseremoteinterfaces => Optional[Boolean],
              anonymousauthentication => Optional[Boolean],
            }]]',
      desc: 'Specifies the zone settings for the Intranet zone.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppZoneSettings',
      mof_is_embedded: true,
    },
    dsc_extranetsettings: {
      type: 'Optional[Struct[{
              customsigninpage => Optional[String],
              enableclientintegration => Optional[Boolean],
              requireuseremoteinterfaces => Optional[Boolean],
              anonymousauthentication => Optional[Boolean],
            }]]',
      desc: 'Specifies the zone settings for the Extranet zone.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppZoneSettings',
      mof_is_embedded: true,
    },
    dsc_default: {
      type: "Optional[Array[Struct[{
              authenticationmethod => Enum['Classic', 'classic', 'WindowsAuthentication', 'windowsauthentication', 'FBA', 'fba', 'Federated', 'federated'],
              membershipprovider => Optional[String],
              usebasicauth => Optional[Boolean],
              roleprovider => Optional[String],
              authenticationprovider => Optional[String],
              windowsauthmethod => Optional[Enum['NTLM', 'ntlm', 'Kerberos', 'kerberos']]
            }]]]",
      desc: 'Specifies the authentication for the Default zone.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppAuthenticationMode[]',
      mof_is_embedded: true,
    },
    dsc_extranet: {
      type: "Optional[Array[Struct[{
              authenticationmethod => Enum['Classic', 'classic', 'WindowsAuthentication', 'windowsauthentication', 'FBA', 'fba', 'Federated', 'federated'],
              membershipprovider => Optional[String],
              usebasicauth => Optional[Boolean],
              roleprovider => Optional[String],
              authenticationprovider => Optional[String],
              windowsauthmethod => Optional[Enum['NTLM', 'ntlm', 'Kerberos', 'kerberos']]
            }]]]",
      desc: 'Specifies the authentication for the Extranet zone.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppAuthenticationMode[]',
      mof_is_embedded: true,
    },
    dsc_intranet: {
      type: "Optional[Array[Struct[{
              authenticationmethod => Enum['Classic', 'classic', 'WindowsAuthentication', 'windowsauthentication', 'FBA', 'fba', 'Federated', 'federated'],
              membershipprovider => Optional[String],
              usebasicauth => Optional[Boolean],
              roleprovider => Optional[String],
              authenticationprovider => Optional[String],
              windowsauthmethod => Optional[Enum['NTLM', 'ntlm', 'Kerberos', 'kerberos']]
            }]]]",
      desc: 'Specifies the authentication for the Intranet zone.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppAuthenticationMode[]',
      mof_is_embedded: true,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_internetsettings: {
      type: 'Optional[Struct[{
              customsigninpage => Optional[String],
              enableclientintegration => Optional[Boolean],
              requireuseremoteinterfaces => Optional[Boolean],
              anonymousauthentication => Optional[Boolean],
            }]]',
      desc: 'Specifies the zone settings for the Internet zone.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppZoneSettings',
      mof_is_embedded: true,
    },
    dsc_customsettings: {
      type: 'Optional[Struct[{
              customsigninpage => Optional[String],
              enableclientintegration => Optional[Boolean],
              requireuseremoteinterfaces => Optional[Boolean],
              anonymousauthentication => Optional[Boolean],
            }]]',
      desc: 'Specifies the zone settings for the Custom zone.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppZoneSettings',
      mof_is_embedded: true,
    },
    dsc_custom: {
      type: "Optional[Array[Struct[{
              authenticationmethod => Enum['Classic', 'classic', 'WindowsAuthentication', 'windowsauthentication', 'FBA', 'fba', 'Federated', 'federated'],
              membershipprovider => Optional[String],
              usebasicauth => Optional[Boolean],
              roleprovider => Optional[String],
              authenticationprovider => Optional[String],
              windowsauthmethod => Optional[Enum['NTLM', 'ntlm', 'Kerberos', 'kerberos']]
            }]]]",
      desc: 'Specifies the authentication for the Custom zone.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppAuthenticationMode[]',
      mof_is_embedded: true,
    },
    dsc_internet: {
      type: "Optional[Array[Struct[{
              authenticationmethod => Enum['Classic', 'classic', 'WindowsAuthentication', 'windowsauthentication', 'FBA', 'fba', 'Federated', 'federated'],
              membershipprovider => Optional[String],
              usebasicauth => Optional[Boolean],
              roleprovider => Optional[String],
              authenticationprovider => Optional[String],
              windowsauthmethod => Optional[Enum['NTLM', 'ntlm', 'Kerberos', 'kerberos']]
            }]]]",
      desc: 'Specifies the authentication for the Internet zone.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppAuthenticationMode[]',
      mof_is_embedded: true,
    },
  },
)
