require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwebappblockedfiletypes',
  dscmeta_resource_friendly_name: 'SPWebAppBlockedFileTypes',
  dscmeta_resource_name: 'MSFT_SPWebAppBlockedFileTypes',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPWebAppBlockedFileTypes resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_ensureallowed: {
      type: 'Optional[Array[String]]',
      desc: 'This list of file types that will always be removedfrom the list for this web app. Types not in this list will be left in the list',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensureblocked: {
      type: 'Optional[Array[String]]',
      desc: 'This list of file types that will always be added to the list for this web app. Types not in this list will be left in the list',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web application to set blocked file types for',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_blocked: {
      type: 'Optional[Array[String]]',
      desc: 'This is a fixed list to use for blocked file types in this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
