require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwebapplication',
  dscmeta_resource_friendly_name: 'SPWebApplication',
  dscmeta_resource_name: 'MSFT_SPWebApplication',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPWebApplication resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_allowlegacyencryption: {
      type: 'Optional[Boolean]',
      desc: 'Specifies that older SSL and TLS protocol versions and cipher suites are allowed to be used with this IIS website (SPSE only and requires Windows Server 2022)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_hostheader: {
      type: 'Optional[String]',
      desc: 'The host header to use for the web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the web application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present if the web app should exist, absent if it should not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitedataservers: {
      type: "Optional[Array[Struct[{
              zone => Enum['Default', 'default', 'Intranet', 'intranet', 'Internet', 'internet', 'Extranet', 'extranet', 'Custom', 'custom'],
              uri => Optional[Array[String]]
            }]]]",
      desc: 'Configure target URIs for the Search crawlers',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppSiteDataServers[]',
      mof_is_embedded: true,
    },
    dsc_useservernameindication: {
      type: 'Optional[Boolean]',
      desc: 'Specifies that the Secure Sockets Layer (SSL) binding of this IIS website should use Server Name Indication (SNI) (SPSE only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_applicationpool: {
      type: 'String',
      desc: 'The name of the application pool to run this site in',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databaseserver: {
      type: 'Optional[String]',
      desc: 'The name of the database server to host the default content DB',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usesqlauthentication: {
      type: 'Optional[Boolean]',
      desc: 'Should SQL Server authentication be used to connect to the database?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applicationpoolaccount: {
      type: 'String',
      desc: 'The name of the managed account to run the app pool with',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databasename: {
      type: 'Optional[String]',
      desc: 'The name of the first content database to be created with this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowanonymous: {
      type: 'Optional[Boolean]',
      desc: 'Should anonymous access be enabled for this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web application',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databasecredentials: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'If using SQL authentication, the SQL credentials to use to connect to the instance',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: 'Specifies the certificate thumbprint of the SSL certificate to be used. Make sure the certificate is added to Certificate Management (SPSE only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'Optional[String]',
      desc: 'The path on the local servers to host the IIS web site from',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_port: {
      type: 'Optional[String]',
      desc: 'The port to run the site on',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_useclassic: {
      type: 'Optional[Boolean]',
      desc: 'Create the web application with Classic authentication (only used during creation of a new web application)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
