require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwebapppeoplepickersettings',
  dscmeta_resource_friendly_name: 'SPWebAppPeoplePickerSettings',
  dscmeta_resource_name: 'MSFT_SPWebAppPeoplePickerSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPWebAppPeoplePickerSettings resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_activedirectorycustomfilter: {
      type: 'Optional[String]',
      desc: 'Sets a customized query filter to send to Active Directory',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_peopleeditoronlyresolvewithinsitecollection: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to check the user against the existing site collection users',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_activedirectorysearchtimeout: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Sets the time-out in seconds when a query is issued to Active Directory',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_onlysearchwithinsitecollection: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to search only the current site collection',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_activedirectorycustomquery: {
      type: 'Optional[String]',
      desc: 'Sets the custom query that is sent to Active Directory',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_searchactivedirectorydomains: {
      type: 'Optional[Array[Struct[{
              customfilter => Optional[String],
              shortdomainname => Optional[String],
              accessaccount => Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]],
              fqdn => String,
              isforest => Boolean
            }]]]',
      desc: 'List of all domains/forests that must be searched',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebAppPPSearchDomain[]',
      mof_is_embedded: true,
    },
  },
)
