require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spworkmanagementserviceapp',
  dscmeta_resource_friendly_name: 'SPWorkManagementServiceApp',
  dscmeta_resource_name: 'MSFT_SPWorkManagementServiceApp',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.6.1',
  docs: 'The DSC SPWorkManagementServiceApp resource type.
         Automatically generated from version 5.6.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the work management service application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_proxyname: {
      type: 'Optional[String]',
      desc: 'The proxy name, if not specified will be /Name of service app/ Proxy',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present to ensure the app exists, Absent to ensure it is removed',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationpool: {
      type: 'Optional[String]',
      desc: 'The name of the application pool this will run in',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_numberofsubscriptionsyncsperewssyncrun: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The number of subscription syncronisations per EWS sync run',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_numberofusersperewssyncbatch: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many users are included in a batch for EWS',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_minimumtimebetweenewssyncsubscriptionsearches: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The minimum amount of time bween EWS sync subscription searches',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_numberofusersewssyncwillprocessatonce: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many users will EWS calls include at once',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_minimumtimebetweensearchqueries: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The minimum time between search queries',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_minimumtimebetweenproviderrefreshes: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The minimum time between provider refreshes',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
